==> deepin-log-viewer_6.1.8.tar.xz: BUILD/translations/deepin-log-viewer_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Počisti dnevnik</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Osveži</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Želite res počistiti dnevnik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danes</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dnevi</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 teden</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mesec</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meseci</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Izvozi</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nujno</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritično</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Razhroščevanje</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prijava</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Zagon</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Izklop</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zelo kritično</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Sledi</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Izvažanje...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Izvoz je uspel</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Izvažanje ni uspelo</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Izvozi datoteko</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Obdobje:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivo:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Seznam programov:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Vrsta dogodka:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uporabnik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Dejanje:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zapis ob zagonu</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zapis ob zaustavitvi</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Zapis prijave</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Razhroščevanje</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nujno</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritično</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Sledi</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zelo kritično</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Datoteka dnevnika je prazna</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Pregledovalnik dnevnika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Pregledovalnik dnevnika je uporabno orodje za pregledovanje sistemskih beležk</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Ni rezultatov iskanja</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivo</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Opravilo</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum in čas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uporabnik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Vir</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Dejanje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Vrsta dogodka</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivo:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Opravilo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum in čas:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>brez</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uporabnik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum in čas</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistemska beležka</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Beležka jedra</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Zagonska beležka</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Beležka dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Beležka Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Beležka Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Programska beležka</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Dogodek zagona-zaustavitve</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Beležka dnf </translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.1.15.tar.xz: BUILD/translations/deepin-log-viewer_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Počisti dnevnik</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Osveži</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Želite res počistiti dnevnik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Danes</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dnevi</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 teden</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mesec</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meseci</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Izvozi</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nujno</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritično</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Razhroščevanje</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prijava</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Zagon</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Izklop</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zelo kritično</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Sledi</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Overitev identitete</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Nadzor diskrecijskega dostopa</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Nadzor mandatnega dostopa</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Oddaljeno</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Potrjevanje dokumenta</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Drugo</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>BESEDILO (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Izvažanje...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Izvoz je uspel</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Izvažanje ni uspelo</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Izvozi datoteko</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Obdobje:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivo:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Vrsta dogodka:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uporabnik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Dejanje:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uporabniško ime:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zapis ob zagonu</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zapis ob zaustavitvi</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Zapis prijave</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Vrsta potrjevanja:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Razhroščevanje</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nujno</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritično</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Sledi</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Zelo kritično</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Datoteka dnevnika je prazna</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Pregledovalnik dnevnika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Pregledovalnik dnevnika je uporabno orodje za pregledovanje sistemskih beležk</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Ni rezultatov iskanja</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivo</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Opravilo</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum in čas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uporabnik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Vir</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Dejanje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Vrsta dogodka</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uporabniško ime</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivo:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Opravilo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum in čas:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>brez</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uporabnik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Ime datoteke</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Čas spremembe</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum in čas</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Dnevnik sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Dnevnik jedra</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Dnevnik zagona</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dnevnik za dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Dnevnik za Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Dnevnik za xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Dnevnik programov</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Dogodek zagona-zaustavitve</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Dnevnik za dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Drugi dnevnik</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Dnevnik po meri</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Dnevnik potrjevanja</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Nimate pravice za ogled</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval osveževanja</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sec</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Brez osveževanja</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Izvozi vse</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Osveži zdaj</translation>
    </message>
</context>
</TS>
